---
jupytext:
  text_representation:
    extension: .md
    format_name: myst
    format_version: 0.13
kernelspec:
  display_name: Python 3 (ipykernel)
  language: python
  name: python3
---

# Do not format Python cells with only IPython stuff

```{code-cell}
# these IPython commands load special backend for notebooks
# %matplotlib widget
%matplotlib inline
```

```{code-cell}
!python3 -c "print(list(set('abcde')))"
```
